searchNodes=[{"doc":"","ref":"Neighborhood.html","title":"Neighborhood","type":"module"},{"doc":"Returns a boolean value indicating whether the given set is a neighborhood of the given x in topological space. Examples iex&gt; topological_space = ...&gt; { ...&gt; MapSet . new ( [ :a , :b , :c ] ) , ...&gt; MapSet . new ( [ ...&gt; MapSet . new ( [ ] ) , ...&gt; MapSet . new ( [ :b ] ) , ...&gt; MapSet . new ( [ :a , :b ] ) , ...&gt; MapSet . new ( [ :a , :b , :c ] ) ...&gt; ] ) ...&gt; } iex&gt; Topology.Neighborhood . is_neighborhood? ( topological_space , :a , MapSet . new ( [ :a , :b ] ) ) true","ref":"Neighborhood.html#is_neighborhood?/3","title":"Neighborhood.is_neighborhood?/3","type":"function"},{"doc":"Operations for sets.","ref":"Set.html","title":"Set","type":"module"},{"doc":"Returns a function set of the given sets. Mathematical expression $$ \\mathfrak{F} (S, T),\\ S^T $$ Examples iex&gt; Set . function_set ( MapSet . new ( [ :a , :b , :c ] ) , MapSet . new ( [ 1 , 2 , 3 ] ) ) MapSet . new ( [ %{ a : 1 } , %{ a : 2 } , %{ a : 3 } , %{ b : 1 } , %{ b : 2 } , %{ b : 3 } , %{ c : 1 } , %{ c : 2 } , %{ c : 3 } ] )","ref":"Set.html#function_set/2","title":"Set.function_set/2","type":"function"},{"doc":"Returns a intersection of the given sets. Mathematical expression $$ \\cap {\\lambda \\in \\Lambda} S {\\lambda} $$ Examples iex&gt; Set . intersection ( MapSet . new ( [ MapSet . new ( [ 3 , 4 , 6 ] ) , MapSet . new ( [ 1 , 4 , 3 ] ) , MapSet . new ( [ 5 , 2 , 3 ] ) ] ) ) MapSet . new ( [ 3 ] )","ref":"Set.html#intersection/1","title":"Set.intersection/1","type":"function"},{"doc":"Returns a power set of the given set. Mathematical expression $$ \\mathfrak{P}(S) $$ Examples iex&gt; Set . power_set ( MapSet . new ( [ 1 , 2 , 3 ] ) ) MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ 1 ] ) , MapSet . new ( [ 2 ] ) , MapSet . new ( [ 3 ] ) , MapSet . new ( [ 1 , 2 ] ) , MapSet . new ( [ 1 , 3 ] ) , MapSet . new ( [ 2 , 3 ] ) , MapSet . new ( [ 1 , 2 , 3 ] ) ] )","ref":"Set.html#power_set/1","title":"Set.power_set/1","type":"function"},{"doc":"Returns a union of the given sets. Mathematical expression $$ \\cup {\\lambda \\in \\Lambda} S {\\lambda} $$ Examples iex&gt; Set . union ( MapSet . new ( [ MapSet . new ( [ 3 , 4 , 6 ] ) , MapSet . new ( [ 1 , 4 , 3 ] ) , MapSet . new ( [ 5 , 2 , 3 ] ) ] ) ) MapSet . new ( [ 1 , 2 , 3 , 4 , 5 , 6 ] )","ref":"Set.html#union/1","title":"Set.union/1","type":"function"},{"doc":"Returns a topology of the given set.","ref":"Topology.html","title":"Topology","type":"module"},{"doc":"Returns a closed set system of the given topological space. Mathematical expression $$ \\mathfrak{U} $$ Theorem A closed set system is a topology if and only if it satisfies the following conditions: $$S \\in \\mathfrak{U},\\ \\phi \\in \\mathfrak{U}$$ $$A_1, A_2 \\in \\mathfrak{U} \\implies A_1 \\cup A_2 \\in \\mathfrak{U}$$ $$A_1, A_2 \\in \\mathfrak{U} \\implies A_1 \\cap A_2 \\in \\mathfrak{U}$$ Examples iex&gt; topological_space = ...&gt; { ...&gt; MapSet . new ( [ :a , :b , :c ] ) , ...&gt; MapSet . new ( [ ...&gt; MapSet . new ( [ ] ) , ...&gt; MapSet . new ( [ :b ] ) , ...&gt; MapSet . new ( [ :a , :b ] ) , ...&gt; MapSet . new ( [ :a , :b , :c ] ) ...&gt; ] ) ...&gt; } iex&gt; Topology . closed_set_system ( topological_space ) MapSet . new ( [ MapSet . new ( [ :a , :b , :c ] ) , MapSet . new ( [ :a , :c ] ) , MapSet . new ( [ :c ] ) , MapSet . new ( [ ] ) , ] )","ref":"Topology.html#closed_set_system/1","title":"Topology.closed_set_system/1","type":"function"},{"doc":"Returns a discrete space of the given set. Mathematical expression $$ (S, \\mathfrak{O}^\\ast) $$ Examples iex&gt; Topology . discrete_space ( MapSet . new ( [ :a , :b ] ) ) { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] ) }","ref":"Topology.html#discrete_space/1","title":"Topology.discrete_space/1","type":"function"},{"doc":"Returns a discreate topology of the given set. Mathematical expression $$ \\mathfrak{O}^\\ast $$ Examples iex&gt; Topology . discrete_topology ( MapSet . new ( [ :a , :b ] ) ) MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] )","ref":"Topology.html#discrete_topology/1","title":"Topology.discrete_topology/1","type":"function"},{"doc":"Returns a discrete space of the given set. Mathematical expression $$ (S, \\mathfrak{O}_\\ast) $$ Examples iex&gt; Topology . indiscrete_space ( MapSet . new ( [ :a , :b ] ) ) { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a , :b ] ) ] ) }","ref":"Topology.html#indiscrete_space/1","title":"Topology.indiscrete_space/1","type":"function"},{"doc":"Returns a indiscreate topology of the given set. Mathematical expression $$ \\mathfrak{O}_\\ast $$ Examples iex&gt; Topology . indiscrete_topology ( MapSet . new ( [ :a , :b ] ) ) MapSet . new ( [ MapSet . new ( ) , MapSet . new ( [ :a , :b ] ) ] )","ref":"Topology.html#indiscrete_topology/1","title":"Topology.indiscrete_topology/1","type":"function"},{"doc":"Returns a boolean indicating whether the given set is an closed set of the given topological space. Examples iex&gt; topological_space = ...&gt; { ...&gt; MapSet . new ( [ :a , :b , :c ] ) , ...&gt; MapSet . new ( [ ...&gt; MapSet . new ( [ ] ) , ...&gt; MapSet . new ( [ :b ] ) , ...&gt; MapSet . new ( [ :a , :b ] ) , ...&gt; MapSet . new ( [ :a , :b , :c ] ) ...&gt; ] ) ...&gt; } iex&gt; Topology . is_closed_set? ( MapSet . new ( [ :c ] ) , topological_space ) true","ref":"Topology.html#is_closed_set?/2","title":"Topology.is_closed_set?/2","type":"function"},{"doc":"Returns a boolean indicating whether the given set is an open set of the given topological space. Examples iex&gt; topological_space = ...&gt; { ...&gt; MapSet . new ( [ :a , :b , :c ] ) , ...&gt; MapSet . new ( [ ...&gt; MapSet . new ( [ ] ) , ...&gt; MapSet . new ( [ :b ] ) , ...&gt; MapSet . new ( [ :a , :b ] ) , ...&gt; MapSet . new ( [ :a , :b , :c ] ) ...&gt; ] ) ...&gt; } iex&gt; Topology . is_open_set? ( MapSet . new ( [ :a , :b ] ) , topological_space ) true","ref":"Topology.html#is_open_set?/2","title":"Topology.is_open_set?/2","type":"function"},{"doc":"See Topology.topologies/1 .","ref":"Topology.html#open_set_systems/1","title":"Topology.open_set_systems/1","type":"function"},{"doc":"Returns a topological spaces of the given set. Mathematical expression $$ (S, \\mathfrak{O}) $$ Examples iex&gt; Topology . topological_spaces ( MapSet . new ( [ :a , :b ] ) ) [ { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a , :b ] ) ] ) } , { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :a , :b ] ) ] ) } , { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] ) } , { MapSet . new ( [ :a , :b ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] ) } ]","ref":"Topology.html#topological_spaces/1","title":"Topology.topological_spaces/1","type":"function"},{"doc":"Returns a topology of the given set. Mathematical expression $$ \\mathfrak{O} \\subset \\mathfrak{P}(S) $$ Examples iex&gt; Topology . topologies ( MapSet . new ( [ :a , :b ] ) ) MapSet . new ( [ MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a , :b ] ) ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :a , :b ] ) ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] ) , MapSet . new ( [ MapSet . new ( [ ] ) , MapSet . new ( [ :a ] ) , MapSet . new ( [ :b ] ) , MapSet . new ( [ :a , :b ] ) ] ) ] )","ref":"Topology.html#topologies/1","title":"Topology.topologies/1","type":"function"},{"doc":"","ref":"Topology.html#t:topological_space/0","title":"Topology.topological_space/0","type":"type"},{"doc":"","ref":"Topology.html#t:topology/0","title":"Topology.topology/0","type":"type"},{"doc":"","ref":"Topology.html#t:underlying_set/0","title":"Topology.underlying_set/0","type":"type"},{"doc":"Operators on topological spaces. Lemma Let $(S, \\mathfrak{O})$ be a topological space and (M \\subset S) be a subset of (S) . Then the following statements are equivalent: $$ \\overline{M^c} = (M^{○})^c $$","ref":"Topology.Operator.html","title":"Topology.Operator","type":"module"},{"doc":"Returns a closure of the given set for topological space. Mathematical expression $$ \\overline{M},\\ M^c $$ Theorem Closure operator has the following properties: $$\\overline{\\phi} = \\phi$$ $$M \\in \\mathfrak{P} (S) \\implies \\overline{M} \\supset M$$ $$M, N \\in \\mathfrak{P}(S) \\implies \\overline{M} \\cup \\overline{N} = \\overline{M \\cup N}$$ $$M \\in \\mathfrak{P}(S) \\implies \\overline{\\overline{M}} = \\overline{M}$$","ref":"Topology.Operator.html#closure_operator/2","title":"Topology.Operator.closure_operator/2","type":"function"},{"doc":"Returns a interior of the given set for topological space. Mathematical expression $$ M^○,\\ M^i $$ Theorem Interior operator has the following properties: $$S^○ = S$$ $$M \\in \\mathfrak{P} (S) \\implies M^○ \\subset M$$ $$M, N \\in \\mathfrak{P}(S) \\implies M^○ \\cap N^○ = (M \\cap N)^○$$ $$M \\in \\mathfrak{P}(S) \\implies M^{○○} = M^○$$ Examples iex&gt; topological_space = ...&gt; { ...&gt; MapSet . new ( [ :a , :b , :c ] ) , ...&gt; MapSet . new ( [ ...&gt; MapSet . new ( [ ] ) , ...&gt; MapSet . new ( [ :b ] ) , ...&gt; MapSet . new ( [ :a , :b ] ) , ...&gt; MapSet . new ( [ :a , :b , :c ] ) ...&gt; ] ) ...&gt; } iex&gt; m = MapSet . new ( [ :a , :b ] ) iex&gt; Topology.Operator . interior_operator ( m , topological_space ) MapSet . new ( [ :a , :b ] )","ref":"Topology.Operator.html#interior_operator/2","title":"Topology.Operator.interior_operator/2","type":"function"}]